@@ -44,8 +44,7 @@ class AkonadiCollectionView;
 class CalendarView;
 class KOWindowList;
 
-namespace Akonadi
-{
+namespace Akonadi {
 class ETMViewStateSaver;
 }
 
@@ -65,10 +64,9 @@ class KORGANIZERPRIVATE_EXPORT ActionManager : public QObject
 {
     Q_OBJECT
 public:
-    ActionManager(KXMLGUIClient *client, CalendarView *widget,
-                  QObject *parent, KOrg::MainWindow *mainWindow,
-                  bool isPart, QMenuBar *menuBar = nullptr);
-    virtual ~ActionManager();
+    ActionManager(KXMLGUIClient *client, CalendarView *widget, QObject *parent,
+                  KOrg::MainWindow *mainWindow, bool isPart, QMenuBar *menuBar = nullptr);
+    ~ActionManager() override;
 
     /** Peform initialization that requires this* to be full constructed */
     void init();
@@ -151,45 +149,27 @@ public:
 
 public Q_SLOTS:
     void openEventEditor(const QString &);
-    void openEventEditor(const QString &summary,
-                         const QString &description,
+    void openEventEditor(const QString &summary, const QString &description,
                          const QStringList &attachments);
-    void openEventEditor(const QString &summary,
-                         const QString &description,
-                         const QStringList &attachments,
-                         const QStringList &attendees);
-    void openEventEditor(const QString &summary,
-                         const QString &description,
-                         const QString &uri,
-                         const QString &file,
-                         const QStringList &attendees,
+    void openEventEditor(const QString &summary, const QString &description,
+                         const QStringList &attachments, const QStringList &attendees);
+    void openEventEditor(const QString &summary, const QString &description, const QString &uri,
+                         const QString &file, const QStringList &attendees,
                          const QString &attachmentMimetype);
-    void openEventEditor(const QString &summary,
-                         const QString &description,
-                         const QStringList &attachmentUris,
-                         const QStringList &attendees,
-                         const QStringList &attachmentMimetypes,
-                         bool attachmentIsInline);
+    void openEventEditor(const QString &summary, const QString &description,
+                         const QStringList &attachmentUris, const QStringList &attendees,
+                         const QStringList &attachmentMimetypes, bool attachmentIsInline);
     void openTodoEditor(const QString &);
-    void openTodoEditor(const QString &summary,
-                        const QString &description,
+    void openTodoEditor(const QString &summary, const QString &description,
                         const QStringList &attachments);
-    void openTodoEditor(const QString &summary,
-                        const QString &description,
-                        const QStringList &attachments,
-                        const QStringList &attendees);
-    void openTodoEditor(const QString &summary,
-                        const QString &description,
-                        const QString &uri,
-                        const QString &file,
-                        const QStringList &attendees,
+    void openTodoEditor(const QString &summary, const QString &description,
+                        const QStringList &attachments, const QStringList &attendees);
+    void openTodoEditor(const QString &summary, const QString &description, const QString &uri,
+                        const QString &file, const QStringList &attendees,
                         const QString &attachmentMimetype);
-    void openTodoEditor(const QString &summary,
-                        const QString &description,
-                        const QStringList &attachmentUris,
-                        const QStringList &attendees,
-                        const QStringList &attachmentMimetypes,
-                        bool attachmentIsInline);
+    void openTodoEditor(const QString &summary, const QString &description,
+                        const QStringList &attachmentUris, const QStringList &attendees,
+                        const QStringList &attachmentMimetypes, bool attachmentIsInline);
 
     void openJournalEditor(const QDate &date);
     void openJournalEditor(const QString &text, const QDate &date);
