@@ -16,25 +16,17 @@
 */
 
 #include "koeventpopupmenutest.h"
-#include "dialog/noteeditdialog.h"
 #include "koeventpopupmenu.h"
-#include <IncidenceEditor/IncidenceDialog>
-#include <IncidenceEditor/IncidenceAttendee>
+#include "dialog/noteeditdialog.h"
+
 #include <CalendarSupport/Utils>
-#include <AkonadiCore/EntityTreeModel>
-#include <Akonadi/Notes/NoteUtils>
-#include <KCalCore/Event>
-#include <KCalCore/Todo>
 
-#include <KMime/KMimeMessage>
-#include <QPushButton>
-#include <qtest.h>
-#include <qtestkeyboard.h>
+#include <IncidenceEditor/IncidenceDialog>
+#include <IncidenceEditor/IncidenceEditor-Ng>
+
 #include <QStandardPaths>
-#include <qtestmouse.h>
 
-#include <QShortcut>
-#include <QAction>
+#include <QTest>
 
 KoEventPopupMenuTest::KoEventPopupMenuTest()
 {
@@ -44,7 +36,7 @@ KoEventPopupMenuTest::KoEventPopupMenuTest()
 void KoEventPopupMenuTest::createEventFromEvent()
 {
     Akonadi::ETMCalendar::Ptr calendar(new Akonadi::ETMCalendar());
-    KOEventPopupMenu menu(0);
+    KOEventPopupMenu menu(nullptr);
 
     KCalCore::Event::Ptr event(new KCalCore::Event());
     Akonadi::Item item;
@@ -64,7 +56,7 @@ void KoEventPopupMenuTest::createEventFromEvent()
 void KoEventPopupMenuTest::createTodoFromTodo()
 {
     Akonadi::ETMCalendar::Ptr calendar(new Akonadi::ETMCalendar());
-    KOEventPopupMenu menu(0);
+    KOEventPopupMenu menu(nullptr);
 
     KCalCore::Todo::Ptr todo(new KCalCore::Todo());
     Akonadi::Item item;
@@ -84,7 +76,7 @@ void KoEventPopupMenuTest::createTodoFromTodo()
 void KoEventPopupMenuTest::createEventFromTodo()
 {
     Akonadi::ETMCalendar::Ptr calendar(new Akonadi::ETMCalendar());
-    KOEventPopupMenu menu(0);
+    KOEventPopupMenu menu(nullptr);
 
     KCalCore::Todo::Ptr todo(new KCalCore::Todo());
     Akonadi::Item item;
@@ -120,7 +112,7 @@ void KoEventPopupMenuTest::createEventFromTodo()
 void KoEventPopupMenuTest::createTodoFromEvent()
 {
     Akonadi::ETMCalendar::Ptr calendar(new Akonadi::ETMCalendar());
-    KOEventPopupMenu menu(0);
+    KOEventPopupMenu menu(nullptr);
 
     KCalCore::Event::Ptr event(new KCalCore::Event());
     Akonadi::Item item;
@@ -156,7 +148,7 @@ void KoEventPopupMenuTest::createTodoFromEvent()
 void KoEventPopupMenuTest::createNoteFromEvent()
 {
     Akonadi::ETMCalendar::Ptr calendar(new Akonadi::ETMCalendar());
-    KOEventPopupMenu menu(0);
+    KOEventPopupMenu menu(nullptr);
 
     KCalCore::Event::Ptr event(new KCalCore::Event());
     Akonadi::Item item;
@@ -194,7 +186,7 @@ void KoEventPopupMenuTest::createNoteFromEvent()
 void KoEventPopupMenuTest::createNoteFromTodo()
 {
     Akonadi::ETMCalendar::Ptr calendar(new Akonadi::ETMCalendar());
-    KOEventPopupMenu menu(0);
+    KOEventPopupMenu menu(nullptr);
 
     KCalCore::Todo::Ptr todo(new KCalCore::Todo());
     Akonadi::Item item;
@@ -232,7 +224,7 @@ void KoEventPopupMenuTest::createNoteFromTodo()
 void KoEventPopupMenuTest::defaultMenuEventVisible()
 {
     Akonadi::ETMCalendar::Ptr calendar(new Akonadi::ETMCalendar());
-    KOEventPopupMenu menu(0);
+    KOEventPopupMenu menu(nullptr);
 
     KCalCore::Event::Ptr event(new KCalCore::Event());
     Akonadi::Item item;
@@ -252,7 +244,7 @@ void KoEventPopupMenuTest::defaultMenuEventVisible()
 void KoEventPopupMenuTest::defaultMenuTodoVisible()
 {
     Akonadi::ETMCalendar::Ptr calendar(new Akonadi::ETMCalendar());
-    KOEventPopupMenu menu(0);
+    KOEventPopupMenu menu(nullptr);
 
     KCalCore::Todo::Ptr todo(new KCalCore::Todo());
 
