@@ -38,7 +38,7 @@ class MultiAgendaView : public KOEventView
     Q_OBJECT
 public:
     explicit MultiAgendaView(QWidget *parent = nullptr);
-    ~MultiAgendaView();
+    ~MultiAgendaView() override;
 
     Akonadi::Item::List selectedIncidences() override;
     KCalCore::DateList selectedIncidenceDates() override;
@@ -92,7 +92,7 @@ class MultiAgendaViewConfigDialog : public QDialog, public EventViews::ConfigDia
     Q_OBJECT
 public:
     explicit MultiAgendaViewConfigDialog(QAbstractItemModel *baseModel, QWidget *parent = nullptr);
-    ~MultiAgendaViewConfigDialog();
+    ~MultiAgendaViewConfigDialog() override;
 
     bool useCustomColumns() const override;
     void setUseCustomColumns(bool);
